==> Git-Repository-Plugin-Blame-v1.3.0.tar.gz: Git-Repository-Plugin-Blame-v1.3.0/README.md <==
Git-Repository-Plugin-Blame
===========================

[![Build Status](https://travis-ci.org/guillaumeaubert/Git-Repository-Plugin-Blame.svg?branch=master)](https://travis-ci.org/guillaumeaubert/Git-Repository-Plugin-Blame)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/Git-Repository-Plugin-Blame/badge.svg?branch=master)](https://coveralls.io/r/guillaumeaubert/Git-Repository-Plugin-Blame?branch=master)
[![CPAN](https://img.shields.io/cpan/v/Git-Repository-Plugin-Blame.svg)](https://metacpan.org/release/Git-Repository-Plugin-Blame)

Bond git and Perl::Critic to blame the right people for violations.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Git::Repository::Plugin::Blame


You can also look for information at:

 * [GitHub (report bugs here)]
   (https://github.com/guillaumeaubert/Git-Repository-Plugin-Blame/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Git-Repository-Plugin-Blame)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Git-Repository-Plugin-Blame)

 * [MetaCPAN]
   (https://metacpan.org/release/Git-Repository-Plugin-Blame)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2012-2015 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> Git-Repository-Plugin-Blame-v1.4.0.tar.gz: Git-Repository-Plugin-Blame-v1.4.0/README.md <==
Git-Repository-Plugin-Blame
===========================

[![Build Status](https://travis-ci.org/guillaumeaubert/Git-Repository-Plugin-Blame.svg?branch=master)](https://travis-ci.org/guillaumeaubert/Git-Repository-Plugin-Blame)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/Git-Repository-Plugin-Blame/badge.svg?branch=master)](https://coveralls.io/r/guillaumeaubert/Git-Repository-Plugin-Blame?branch=master)
[![CPAN](https://img.shields.io/cpan/v/Git-Repository-Plugin-Blame.svg)](https://metacpan.org/release/Git-Repository-Plugin-Blame)
[![License](https://img.shields.io/badge/license-Perl%205-blue.svg)](http://dev.perl.org/licenses/)

Add a blame() method to Git::Repository.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Git::Repository::Plugin::Blame


You can also look for information at:

 * [GitHub (report bugs here)]
   (https://github.com/guillaumeaubert/Git-Repository-Plugin-Blame/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Git-Repository-Plugin-Blame)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Git-Repository-Plugin-Blame)

 * [MetaCPAN]
   (https://metacpan.org/release/Git-Repository-Plugin-Blame)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2012-2017 Guillaume Aubert.

This code is free software; you can redistribute it and/or modify it under the
same terms as Perl 5 itself.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the LICENSE file for more details.
